@@ -1,7 +1,7 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.30"
+__version__ = "1.33"
 __author__ = "Jonathan Bolo"
 
 from ctypes.wintypes import PUINT
@@ -133,8 +133,8 @@ def upload_file_sftp(filename:StrOrPathList,
                 for i in lista_archivos:
                     log.debug ("Subiendo archivo: " + str(i))
                     server.put(
-                        i, 
-                        (PurePosixPath(destine_path) / i.name).as_posix())
+                        str(i), 
+                        i.name)
                     
             else:
                 try:
@@ -151,13 +151,12 @@ def upload_file_sftp(filename:StrOrPathList,
 
                 for file in dir_local.iterdir():
 
-                    if fnmatch.fnmatch(file, filename.name):
+                    if fnmatch.fnmatch(file.name, filename.name):
                         flag_exists = True
-                        filename_local = dir_local / file
-                        log.debug ("Subiendo archivo: " + str(filename_local))
+                        log.debug ("Subiendo archivo: " + str(file))
                         server.put(
-                            filename_local, 
-                            (PurePosixPath(destine_path) / file).as_posix())
+                            str(file), 
+                            file.name)
                 
                 if not flag_exists:
                     raise Exception("No se encontró coincidencias para: " + 
@@ -529,7 +528,7 @@ def move_sftp(filenames:dict,
             
             for origin, destine in filenames.items():
                 try:
-                    pendientes[PurePosixPath(origin)] = PurePosixPath(destine)
+                    pendientes[str(PurePosixPath(origin))] = str(PurePosixPath(destine))
                 except:
                     raise Exception("Rutas ingresadas estan erroneas.")
                 
@@ -1327,7 +1326,11 @@ def lista_feriados(anio):
     
     return list(lista_feriados)
 
-def notifica_exception(exception=None, notifica=None, lista_exceptions_bl=[], subject_replace=None, body_replace=None):
+def notifica_exception(exception=None, 
+                       notifica=None, 
+                       lista_exceptions_bl=[], 
+                       subject_replace=None, 
+                       body_replace=None):
     """Función que notifica todas las excepciones. Si alguna se encuentra en la lista blacklist, no se notifica"""
     if not subject_replace:
         subject_replace = "Error"
@@ -1336,9 +1339,21 @@ def notifica_exception(exception=None, notifica=None, lista_exceptions_bl=[], su
     
     if str(type(exception).__name__).startswith("ID"):
         if type(exception).__name__ not in lista_exceptions_bl:
-            notifica.enviar_correo({'[TEXTO]':subject_replace}, {'[TEXTO]':str(exception)})
+            if type(subject_replace) is dict:
+                subject=subject_replace
+            else:
+                subject={'[TEXTO]':subject_replace}
+                
+            notifica.enviar_correo(subject,
+                                   {'[TEXTO]':str(exception)})
     else:
-        notifica.enviar_correo({'[TEXTO]':subject_replace}, {'[TEXTO]':body_replace + str(exception)})
+        if type(subject_replace) is dict:
+            subject=subject_replace
+        else:
+            subject={'[TEXTO]':subject_replace}
+            
+        notifica.enviar_correo(subject,
+                               {'[TEXTO]':body_replace + str(exception)})
 
 def timed(func):
     """Decorador para loggear el tiempo de ejecucion de una funcion.
